@@ -7,6 +7,7 @@ from zeep import ns, plugins, wsa
 from zeep.exceptions import Fault, TransportError, XMLSyntaxError
 from zeep.loader import parse_xml
 from zeep.utils import as_qname, get_media_type, qname_attr
+from zeep.wsdl.messages.xop import process_xop
 from zeep.wsdl.attachments import MessagePack
 from zeep.wsdl.definitions import Binding, Operation
 from zeep.wsdl.messages import DocumentMessage, RpcMessage
@@ -97,9 +98,9 @@ class SoapBinding(Binding):
         :type options: dict
         :param operation: The operation object from which this is a reply
         :type operation: zeep.wsdl.definitions.Operation
-        :param args: The *args to pass to the operation
+        :param args: The args to pass to the operation
         :type args: tuple
-        :param kwargs: The **kwargs to pass to the operation
+        :param kwargs: The kwargs to pass to the operation
         :type kwargs: dict
 
         """
@@ -112,6 +113,11 @@ class SoapBinding(Binding):
             options['address'], envelope, http_headers)
 
         operation_obj = self.get(operation)
+
+        # If the client wants to return the raw data then let's do that.
+        if client.raw_response:
+            return response
+
         return self.process_reply(client, operation_obj, response)
 
     def process_reply(self, client, operation, response):
@@ -137,7 +143,6 @@ class SoapBinding(Binding):
         if media_type == 'multipart/related':
             decoder = MultipartDecoder(
                 response.content, content_type, response.encoding or 'utf-8')
-
             content = decoder.parts[0].content
             if len(decoder.parts) > 1:
                 message_pack = MessagePack(parts=decoder.parts[1:])
@@ -145,12 +150,20 @@ class SoapBinding(Binding):
             content = response.content
 
         try:
-            doc = parse_xml(content, self.transport)
+            doc = parse_xml(
+                content, self.transport,
+                strict=client.wsdl.strict,
+                xml_huge_tree=client.xml_huge_tree)
         except XMLSyntaxError:
             raise TransportError(
-                u'Server returned HTTP status %d (%s)'
+                'Server returned HTTP status %d (%s)'
                 % (response.status_code, response.content))
 
+        # Check if this is an XOP message which we need to decode first
+        if message_pack:
+            if process_xop(doc, message_pack):
+                message_pack = None
+
         if client.wsse:
             client.wsse.verify(doc)
 
@@ -191,6 +204,9 @@ class SoapBinding(Binding):
     @classmethod
     def parse(cls, definitions, xmlelement):
         """
+
+        Definition::
+
             <wsdl:binding name="nmtoken" type="qname"> *
                 <-- extensibility element (1) --> *
                 <wsdl:operation name="nmtoken"> *
@@ -338,12 +354,15 @@ class SoapOperation(Operation):
                 "{%s}Envelope root element. The root element found is %s "
             ) % (envelope_qname.namespace, envelope.tag))
 
-        return self.output.deserialize(envelope)
+        if self.output:
+            return self.output.deserialize(envelope)
 
     @classmethod
     def parse(cls, definitions, xmlelement, binding, nsmap):
         """
 
+        Definition::
+
             <wsdl:operation name="nmtoken"> *
                 <soap:operation soapAction="uri"? style="rpc|document"?>?
                 <wsdl:input name="nmtoken"? > ?
