@@ -1,12 +1,19 @@
+"""
+    zeep.wsdl.messages.soap
+    ~~~~~~~~~~~~~~~~~~~~~~~
+
+"""
 import copy
 from collections import OrderedDict
 
 from lxml import etree
 from lxml.builder import ElementMaker
 
+from zeep import ns
 from zeep import exceptions, xsd
 from zeep.utils import as_qname
 from zeep.wsdl.messages.base import ConcreteMessage, SerializedMessage
+from zeep.wsdl.messages.multiref import process_multiref
 
 __all__ = [
     'DocumentMessage',
@@ -15,8 +22,19 @@ __all__ = [
 
 
 class SoapMessage(ConcreteMessage):
-    """Base class for the SOAP Document and RPC messages"""
+    """Base class for the SOAP Document and RPC messages
 
+    :param wsdl: The main wsdl document
+    :type wsdl: zeep.wsdl.Document
+    :param name:
+    :param operation: The operation to which this message belongs
+    :type operation: zeep.wsdl.bindings.soap.SoapOperation
+    :param type: 'input' or 'output'
+    :type type: str
+    :param nsmap: The namespace mapping
+    :type nsmap: dict
+
+    """
     def __init__(self, wsdl, name, operation, type, nsmap):
         super(SoapMessage, self).__init__(wsdl, name, operation)
         self.nsmap = nsmap
@@ -71,6 +89,7 @@ class SoapMessage(ConcreteMessage):
         if not self.envelope:
             return None
 
+
         body = envelope.find('soap-env:Body', namespaces=self.nsmap)
         body_result = self._deserialize_body(body)
 
@@ -96,7 +115,8 @@ class SoapMessage(ConcreteMessage):
         result = next(iter(result.__values__.values()))
         if isinstance(result, xsd.CompoundValue):
             children = result._xsd_type.elements
-            if len(children) == 1:
+            attributes = result._xsd_type.attributes
+            if len(children) == 1 and len(attributes) == 0:
                 item_name, item_element = children[0]
                 retval = getattr(result, item_name)
                 return retval
@@ -332,7 +352,7 @@ class SoapMessage(ConcreteMessage):
     def _resolve_header(self, info, definitions, parts):
         name = etree.QName(self.nsmap['soap-env'], 'Header')
 
-        container = xsd.All()
+        container = xsd.All(consume_other=True)
         if not info:
             return xsd.Element(name, xsd.ComplexType(container))
 
@@ -358,6 +378,20 @@ class DocumentMessage(SoapMessage):
     """In the document message there are no additional wrappers, and the
     message parts appear directly under the SOAP Body element.
 
+    .. inheritance-diagram:: zeep.wsdl.messages.soap.DocumentMessage
+       :parts: 1
+
+    :param wsdl: The main wsdl document
+    :type wsdl: zeep.wsdl.Document
+    :param name:
+    :param operation: The operation to which this message belongs
+    :type operation: zeep.wsdl.bindings.soap.SoapOperation
+    :param type: 'input' or 'output'
+    :type type: str
+    :param nsmap: The namespace mapping
+    :type nsmap: dict
+
+
     """
 
     def __init__(self, *args, **kwargs):
@@ -412,6 +446,20 @@ class RpcMessage(SoapMessage):
     identically to the corresponding parameter of the call.  Parts are arranged
     in the same order as the parameters of the call.
 
+    .. inheritance-diagram:: zeep.wsdl.messages.soap.DocumentMessage
+       :parts: 1
+
+
+    :param wsdl: The main wsdl document
+    :type wsdl: zeep.wsdl.Document
+    :param name:
+    :param operation: The operation to which this message belongs
+    :type operation: zeep.wsdl.bindings.soap.SoapOperation
+    :param type: 'input' or 'output'
+    :type type: str
+    :param nsmap: The namespace mapping
+    :type nsmap: dict
+
     """
 
     def _resolve_body(self, info, definitions, parts):
@@ -449,6 +497,8 @@ class RpcMessage(SoapMessage):
         element.
 
         """
+        process_multiref(body_element)
+
         response_element = body_element.getchildren()[0]
         if self.body:
             result = self.body.parse(response_element, self.wsdl.types)
