@@ -1,13 +1,20 @@
+"""
+    zeep.wsdl.wsdl
+    ~~~~~~~~~~~~~~
+
+"""
 from __future__ import print_function
 
 import logging
 import operator
 import os
+import warnings
 from collections import OrderedDict
 
 import six
 from lxml import etree
 
+from zeep.exceptions import IncompleteMessage
 from zeep.loader import absolute_location, is_relative_path, load_external
 from zeep.utils import findall_multiple_ns
 from zeep.wsdl import parse
@@ -33,6 +40,16 @@ class Document(object):
     resolves references which were not yet available during the initial
     parsing phase.
 
+
+    :param location: Location of this WSDL
+    :type location: string
+    :param transport: The transport object to be used
+    :type transport: zeep.transports.Transport
+    :param base: The base location of this document
+    :type base: str
+    :param strict: Indicates if strict mode is enabled
+    :type strict: bool
+
     """
 
     def __init__(self, location, transport, base=None, strict=True):
@@ -40,11 +57,6 @@ class Document(object):
 
         The root definition properties are exposed as entry points.
 
-        :param location: Location of this WSDL
-        :type location: string
-        :param transport: The transport object to be used
-        :type transport: zeep.transports.Transport
-
         """
         if isinstance(location, six.string_types):
             if is_relative_path(location):
@@ -133,9 +145,18 @@ class Document(object):
 
 
 class Definition(object):
-    """The Definition represents one wsdl:definition within a Document."""
+    """The Definition represents one wsdl:definition within a Document.
+
+    :param wsdl: The wsdl
+
+    """
 
     def __init__(self, wsdl, doc, location):
+        """fo
+
+        :param wsdl: The wsdl
+
+        """
         logger.debug("Creating definition for %s", location)
         self.wsdl = wsdl
         self.location = location
@@ -257,6 +278,8 @@ class Definition(object):
         If the wsdl:types doesn't container an xml schema then an empty schema
         is returned instead.
 
+        Definition::
+
             <definitions .... >
                 <types>
                     <xsd:schema .... />*
@@ -285,6 +308,9 @@ class Definition(object):
 
     def parse_messages(self, doc):
         """
+
+        Definition::
+
             <definitions .... >
                 <message name="nmtoken"> *
                     <part name="nmtoken" element="qname"? type="qname"?/> *
@@ -297,14 +323,20 @@ class Definition(object):
         """
         result = {}
         for msg_node in doc.findall("wsdl:message", namespaces=NSMAP):
-            msg = parse.parse_abstract_message(self, msg_node)
-            result[msg.name.text] = msg
-            logger.debug("Adding message: %s", msg.name.text)
+            try:
+                msg = parse.parse_abstract_message(self, msg_node)
+            except IncompleteMessage as exc:
+                warnings.warn(str(exc))
+            else:
+                result[msg.name.text] = msg
+                logger.debug("Adding message: %s", msg.name.text)
         return result
 
     def parse_ports(self, doc):
         """Return dict with `PortType` instances as values
 
+        Definition::
+
             <wsdl:definitions .... >
                 <wsdl:portType name="nmtoken">
                     <wsdl:operation name="nmtoken" .... /> *
@@ -329,7 +361,7 @@ class Definition(object):
         HTTP Post. The detection of the type of bindings is done by the
         bindings themselves using the introspection of the xml nodes.
 
-        XML Structure::
+        Definition::
 
             <wsdl:definitions .... >
                 <wsdl:binding name="nmtoken" type="qname"> *
@@ -391,6 +423,9 @@ class Definition(object):
 
     def parse_service(self, doc):
         """
+
+        Definition::
+
             <wsdl:definitions .... >
                 <wsdl:service .... > *
                     <wsdl:port name="nmtoken" binding="qname"> *
