@@ -3,8 +3,9 @@ from collections import OrderedDict
 
 from lxml import etree
 
-from zeep import exceptions
-from zeep import ns
+from zeep import exceptions, ns
+from zeep.loader import load_external
+from zeep.xsd import const
 from zeep.xsd.elements import builtins as xsd_builtins_elements
 from zeep.xsd.types import builtins as xsd_builtins_types
 from zeep.xsd.visitor import SchemaVisitor
@@ -116,6 +117,15 @@ class Schema(object):
 
         self._prefix_map_auto = self._create_prefix_map()
 
+    def add_document_by_url(self, url):
+        schema_node = load_external(
+            url,
+            self._transport,
+            strict=self.strict)
+
+        document = self.create_new_document(schema_node, url=url)
+        document.resolve()
+
     def get_element(self, qname):
         """Return a global xsd.Element object with the given qname
 
@@ -136,7 +146,7 @@ class Schema(object):
             return self._get_instance(qname, 'get_type', 'type')
         except exceptions.NamespaceError as exc:
             if fail_silently:
-                logger.info(str(exc))
+                logger.debug(str(exc))
             else:
                 raise
 
@@ -284,7 +294,7 @@ class Schema(object):
         return namespace in self._documents
 
     def _add_schema_document(self, document):
-        logger.info("Add document with tns %s to schema %s", document.namespace, id(self))
+        logger.debug("Add document with tns %s to schema %s", document.namespace, id(self))
         documents = self._documents.setdefault(document.namespace, [])
         documents.append(document)
 
@@ -305,6 +315,13 @@ class Schema(object):
         :rtype: list of SchemaDocument
 
         """
+        if (
+            namespace not in self._documents
+            and namespace in const.AUTO_IMPORT_NAMESPACES
+        ):
+            logger.debug("Auto importing missing known schema: %s", namespace)
+            self.add_document_by_url(namespace)
+
         if namespace not in self._documents:
             if fail_silently:
                 return []
@@ -363,7 +380,7 @@ class SchemaDocument(object):
         visitor.visit_schema(node)
 
     def resolve(self):
-        logger.info("Resolving in schema %s", self)
+        logger.debug("Resolving in schema %s", self)
 
         if self._resolved:
             return
@@ -374,10 +391,23 @@ class SchemaDocument(object):
                 schema.resolve()
 
         def _resolve_dict(val):
-            for key, obj in val.items():
-                new = obj.resolve()
-                assert new is not None, "resolve() should return an object"
-                val[key] = new
+            try:
+                for key, obj in val.items():
+                    new = obj.resolve()
+                    assert new is not None, "resolve() should return an object"
+                    val[key] = new
+            except exceptions.LookupError as exc:
+                raise exceptions.LookupError(
+                    (
+                        "Unable to resolve %(item_name)s %(qname)s in "
+                        "%(file)s. (via %(parent)s)"
+                    ) % {
+                        'item_name': exc.item_name,
+                        'item_name': exc.item_name,
+                        'qname': exc.qname,
+                        'file': exc.location,
+                        'parent': obj.qname,
+                    })
 
         _resolve_dict(self._attribute_groups)
         _resolve_dict(self._attributes)
@@ -473,10 +503,13 @@ class SchemaDocument(object):
             raise exceptions.LookupError((
                 "No %(item_name)s '%(localname)s' in namespace %(namespace)s. " +
                 "Available %(item_name_plural)s are: %(known_items)s"
-            ) % {
-                'item_name': item_name,
-                'item_name_plural': item_name + 's',
-                'localname': qname.localname,
-                'namespace': qname.namespace,
-                'known_items': known_items or ' - '
-            })
+                ) % {
+                    'item_name': item_name,
+                    'item_name_plural': item_name + 's',
+                    'localname': qname.localname,
+                    'namespace': qname.namespace,
+                    'known_items': known_items or ' - '
+                },
+                qname=qname,
+                item_name=item_name,
+                location=self._location)
