@@ -9,7 +9,8 @@ from zeep.loader import absolute_location, load_external
 from zeep.utils import as_qname, qname_attr
 from zeep.xsd import elements as xsd_elements
 from zeep.xsd import types as xsd_types
-from zeep.xsd.const import xsd_ns
+from zeep.xsd.const import xsd_ns, AUTO_IMPORT_NAMESPACES
+from zeep.xsd.types.unresolved import UnresolvedCustomType, UnresolvedType
 
 logger = logging.getLogger(__name__)
 
@@ -252,12 +253,28 @@ class SchemaVisitor(object):
             new = etree.Element(schema_node.tag, nsmap=nsmap)
             for child in schema_node:
                 new.append(child)
+            for key, value in schema_node.attrib.items():
+                new.set(key, value)
             schema_node = new
 
-        # Iterate directly over the children
+        # Use the element/attribute form defaults from the schema while
+        # processing the nodes.
+        element_form_default = self.document._element_form
+        attribute_form_default = self.document._attribute_form
+        base_url = self.document._base_url
+
+        self.document._element_form = schema_node.get('elementFormDefault', 'unqualified')
+        self.document._attribute_form = schema_node.get('attributeFormDefault', 'unqualified')
+        self.document._base_url = absolute_location(location, self.document._base_url)
+
+        # Iterate directly over the children.
         for child in schema_node:
             self.process(child, parent=schema_node)
 
+        self.document._element_form = element_form_default
+        self.document._attribute_form = attribute_form_default
+        self.document._base_url = base_url
+
     def visit_element(self, node, parent):
         """
 
@@ -383,9 +400,8 @@ class SchemaVisitor(object):
             match = re.match('([^\[]+)', array_type)
             if match:
                 array_type = match.groups()[0]
-                qname = as_qname(
-                    array_type, node.nsmap, self.document._target_namespace)
-                array_type = xsd_types.UnresolvedType(qname, self.schema)
+                qname = as_qname(array_type, node.nsmap)
+                array_type = UnresolvedType(qname, self.schema)
 
         # If the elment has a ref attribute then all other attributes cannot
         # be present. Short circuit that here.
@@ -455,8 +471,7 @@ class SchemaVisitor(object):
         child = items[0]
         if child.tag == tags.restriction:
             base_type = self.visit_restriction_simple_type(child, node)
-            xsd_type = xsd_types.UnresolvedCustomType(
-                qname, base_type, self.schema)
+            xsd_type = UnresolvedCustomType(qname, base_type, self.schema)
 
         elif child.tag == tags.list:
             xsd_type = self.visit_list(child, node)
@@ -552,6 +567,7 @@ class SchemaVisitor(object):
         complex type that contains mixed content or elements only.
 
         Definition::
+
             <complexContent
               id = ID
               mixed = Boolean
@@ -591,6 +607,7 @@ class SchemaVisitor(object):
         elements.
 
         Definition::
+
             <simpleContent
               id = ID
               {any attributes with non-schema Namespace}...>
@@ -615,6 +632,7 @@ class SchemaVisitor(object):
     def visit_restriction_simple_type(self, node, parent):
         """
         Definition::
+
             <restriction
               base = QName
               id = ID
@@ -643,6 +661,7 @@ class SchemaVisitor(object):
     def visit_restriction_simple_content(self, node, parent):
         """
         Definition::
+
             <restriction
               base = QName
               id = ID
@@ -667,6 +686,7 @@ class SchemaVisitor(object):
 
     def visit_restriction_complex_content(self, node, parent):
         """
+
         Definition::
 
             <restriction
@@ -700,6 +720,7 @@ class SchemaVisitor(object):
 
     def visit_extension_complex_content(self, node, parent):
         """
+
         Definition::
 
             <extension
@@ -735,7 +756,9 @@ class SchemaVisitor(object):
 
     def visit_extension_simple_content(self, node, parent):
         """
+
         Definition::
+
             <extension
               base = QName
               id = ID
@@ -892,8 +915,10 @@ class SchemaVisitor(object):
         :type parent: lxml.etree._Element
 
         """
+        min_occurs, max_occurs = _process_occurs_attrs(node)
 
-        result = self.process_reference(node)
+        result = self.process_reference(
+            node, min_occurs=min_occurs, max_occurs=max_occurs)
         if result:
             return result
 
@@ -987,7 +1012,7 @@ class SchemaVisitor(object):
         types = []
         if members:
             for member in members.split():
-                qname = as_qname(member, node.nsmap, self.document._target_namespace)
+                qname = as_qname(member, node.nsmap)
                 xsd_type = self._get_type(qname)
                 types.append(xsd_type)
         else:
@@ -1097,7 +1122,7 @@ class SchemaVisitor(object):
     def _get_type(self, name):
         assert name is not None
         name = self._create_qname(name)
-        return xsd_types.UnresolvedType(name, self.schema)
+        return UnresolvedType(name, self.schema)
 
     def _create_qname(self, name):
         if not isinstance(name, etree.QName):
@@ -1113,9 +1138,11 @@ class SchemaVisitor(object):
         # that fact and handle it by auto-importing the schema if it is
         # referenced.
         if (
-            name.namespace == 'http://schemas.xmlsoap.org/soap/encoding/' and
-            not self.document.is_imported(name.namespace)
+            name.namespace in AUTO_IMPORT_NAMESPACES
+            and not self.document.is_imported(name.namespace)
         ):
+            logger.debug(
+                "Auto importing missing known schema: %s", name.namespace)
             import_node = etree.Element(
                 tags.import_,
                 namespace=name.namespace, schemaLocation=name.namespace)
